@@ -46,7 +46,7 @@
 //! The `reverse_grapheme_clusters_in_place` function from this crate performs this same operation,
 //! but performs the reversal in-place rather than allocating a new string.
 //!
-//! # Algorithm
+//! ## Algorithm
 //!
 //! The implementation is very simple. It makes two passes over the string's contents:
 //!
@@ -56,7 +56,7 @@
 //! After the second pass, each grapheme cluster has been reversed twice, so its bytes are now back
 //! in their original order, but the clusters are now in the opposite order within the string.
 //!
-//! # no_std
+//! ## no_std
 //!
 //! This crate does not depend on libstd, so it can be used in [`no_std` projects][3].
 //!
@@ -144,6 +144,11 @@ mod tests {
         assert_eq!(a, b);
     }
 
+    #[test]
+    fn test_empty() {
+        test_rev("", "");
+    }
+
     #[test]
     fn test_ascii() {
         test_rev("Hello", "olleH");
